import pathlib

import seisbench.models as sbm

from .model_runner import ModelRunner


class GPDModelRunner(ModelRunner):

    model_type = "GPD"

    def __init__(self, weights_name="original", output_dir=pathlib.Path("."), **kwargs):
        self.model_name = getattr(sbm, GPDModelRunner.model_type)
        super(GPDModelRunner, self).__init__(
            weights_name=weights_name, output_dir=output_dir, **kwargs
        )

    def process_kwargs(self, **kwargs):
        self.stride = int(kwargs.get("stride", 10))
        self.threshold_p = float(kwargs.get("threshold_p", 0.75))
        self.threshold_s = float(kwargs.get("threshold_s", 0.75))

        self.annotate_kwargs = {
            "stride": self.stride,
        }

        self.classify_kwargs = self.model.default_args.copy()
        self.classify_kwargs["P_threshold"] = self.threshold_p
        self.classify_kwargs["S_threshold"] = self.threshold_s
